package packageForL9L10;

import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;

/**
 * This class encapsulates a very simple controller. This controller listens for
 * mouse events. If a mouse event is detected, then this controller will ask the
 * model to modify itself (by indicating that the first dot should be nudged to
 * the right).
 * 
 * @author mb
 * 
 */
public class DotController implements MouseListener {

	private SimpleThreeDotModel_v2 theModel;
	private DotPanel theView;

	/**
	 * Instantiates the controller. The controller installs itself upon the view
	 * and thereby receives any mouse events that are dispatched from the view.
	 * The controller implements a very simple behaviour - any mouse click
	 * causes the first dot to be nudged to the right. The controller also takes
	 * the passed model so that it can instruct the model to change itself
	 * accordingly on the basis of user input.
	 * 
	 * @param view
	 * @param model
	 */
	public DotController(DotPanel view, SimpleThreeDotModel_v2 model) {
		theModel = model;
		theView = view;

		/**
		 * The widgets of the view will generate events. We want the controller
		 * to be aware of such events so that it can update the model
		 * accordingly.
		 * 
		 */
		theView.addMouseListener(this);

	}

	/**
	 * Any mouse click causes dot 1 in the model to be nudged to the right.
	 * Hint: look at the API of the class SimpleThreeDotModel to see how this
	 * method might accomplish this.
	 */
	public void mouseClicked(MouseEvent e) {
		theModel.nudgeToRightDot1();
	}

	/**
	 * Does nothing
	 */
	public void mousePressed(MouseEvent e) {
	}

	/**
	 * Does nothing
	 */
	public void mouseReleased(MouseEvent e) {
	}

	/**
	 * Does nothing
	 */
	public void mouseEntered(MouseEvent e) {
	}

	/**
	 * Does nothing
	 */
	public void mouseExited(MouseEvent e) {
	}

}
